@@ -128,6 +128,18 @@ if (!isset($sub_section) && !isset($blog)) {
 	<a href="index.php?amn=blg_blog_edit"<?php echo $link_css;?>><?php echo $lang['menu_create'];?></a>
 	&nbsp;
 	<?php }?>
+
+	
+	<?php
+	if ($_SESSION['user_mod_permission'] & $resource['module']['blg']['maint']) {
+	$link_css = "";
+	if ($page_name_short == "maintain") {
+		$link_css = " class=\"highlight\"";
+	}
+	?>
+	<a href="index.php?amn=blg_maintain"<?php echo $link_css;?>><?php echo $lang['menu_maintain'];?></a>
+	&nbsp;
+	<?php }?>
 <?php }?>
 
 <?php
