@@ -49,6 +49,27 @@
 			
 		<div class="box_mid">
 			<div class="content">
+				<?php
+				if ($blog['status_id'] != $blog_config['status']['live']) {
+				?>
+				<div class="picture" style="padding:10px; margin-bottom:20px; width:488px">
+					<?php
+					if (!empty($blog_config['owner_allow_to_live_status'])) {
+					?>
+						<?php echo $lang['txt_status_not_live_owner_set'];?><br />
+
+						<p align="right">
+							<a href="index.php?amn=blg_item&amp;blog_id=<?php echo $blog['blog_id'];?>&amp;set_status_live=1"><?php echo $lang['href_set_to_live'];?></a><br />
+						</p>
+					<?php
+					}
+					else {
+					?>
+						<?php echo $lang['txt_status_not_live'];?><br />
+					<?php }?>
+				</div>
+				<?php }?>
+				
 				<?php
 				if (isset($_SESSION['user_id'])) {
 				?>
@@ -244,6 +265,27 @@
 		
 		<div class="box_mid">
 			<div class="content">
+				<?php
+				if ($blog['status_id'] != $blog_config['status']['live']) {
+				?>
+				<div class="picture" style="padding:10px; margin-bottom:20px; width:488px">
+					<?php
+					if (!empty($blog_config['owner_allow_to_live_status'])) {
+					?>
+						<?php echo $lang['txt_status_not_live_owner_set'];?><br />
+
+						<p align="right">
+							<a href="index.php?amn=blg_item&amp;blog_id=<?php echo $blog['blog_id'];?>&amp;set_status_live=1"><?php echo $lang['href_set_to_live'];?></a><br />
+						</p>
+					<?php
+					}
+					else {
+					?>
+						<?php echo $lang['txt_status_not_live'];?><br />
+					<?php }?>
+				</div>
+				<?php }?>
+				
 				<p>
 					<?php echo $lang['txt_no_entries'];?><br />
 				</p>
